#!/bin/bash

# This is a script to send a notification from OTRS to Mattermost.
# Create a new Generic Agent and select "TicketCreate" under event based events.
# Finally, put in the path to the script into the command box.
# Of course you could use it for different notifications, but OTRS is only giving the ticket number and id to the script.
#
# original source: https://gist.github.com/meilon/1ddf647063485e0b64bc

# space seperated please
hook_targets=""
protected_queues=""


otrs="https://helpdesk.mpib-berlin.mpg.de"
exotrs="https://ex-ts.mpib-berlin.mpg.de" # fetch icon from non-intra resource
mattermost="https://chat.mpib-berlin.mpg.de/hooks"
header="Content-Type: application/json"


# we only get ticket id, everything else needs to be picked from the sql db
# for possible values check output of:
#
#   sudo -H -u otrs psql -d otrs2 -A -t -c "select column_name,data_type from INFORMATION_SCHEMA.COLUMNS where TABLE_NAME='ticket'"
ticket_id=$2


sql="select t.title,t.customer_user_id,q.name,t.id FROM ticket AS t JOIN queue as q ON (t.queue_id = q.id) WHERE t.id = ${ticket_id}"

# mostly this hook is being called as user "otrs", but once in a while it's
# "www-data" - very encouraging behaviour...
if [ "$USER" = "otrs" ] ; then
    # use peer authentication for otrs user
    ticket_data=$(psql -d otrs2 -A -t -c "$sql")
else
    # rely on ~/.pgpass otherwise - configure manually, see /etc/otrs/database.pm
    ticket_data=$(psql -h localhost -U otrs -d otrs2 -A -t -c "$sql")
fi

# minimal cleanup and defaults, quote at least "
if [ "$ticket_data" != "" ] ; then
    ticket_title=$(echo $ticket_data | cut -d"|" -f1 | sed 's#\"#\\"#g')
    ticket_email=$(echo $ticket_data | cut -d"|" -f2 | sed 's#\"#\\"#g' | cut -d"@" -f1)
    ticket_queue=$(echo $ticket_data | cut -d"|" -f3 | sed 's#\"#\\"#g')
fi
if [ "$ticket_title" = "" ] ; then
    ticket_title="Unkonwn (#${ticket_id})"
fi
if [ "$ticket_email" = "" ] ; then
    ticket_email="Unkonwn"
fi
if [ "$ticket_queue" = "" ] ; then
    ticket_queue="Unkonwn"
fi

# stop if queue is part of data sensitive / protected group
for protected_queue in $protected_queues; do
    if [ "$ticket_queue" = "$protected_queue" ] ; then
        echo "not sending notification (protected queue)"
        exit 0
    fi
done

request_body=$(< <(cat <<EOF
{
  "username": "OTRSbot",
  "text": "New :ticket: in **$ticket_queue**: [**${ticket_title}**](<$otrs/otrs/index.pl?Action=AgentTicketZoom;TicketID=${ticket_id}>)  from *$ticket_email*",
  "icon_url": "$exotrs/otrs-web/skins/Agent/default/img/icons/apple-touch-icon.png"
}
EOF
))

for hook_target in $hook_targets ; do
    curl -q -i -X POST -H "$header" -d "$request_body" "${mattermost}/${hook_target}" >/dev/null 2>&1
done
exit 0
